@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2013-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2013-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -35,7 +35,7 @@ from cubicweb.web.views.urlrewrite import rgx_action, SchemaBasedRewriter
 from cubicweb import Binary
 from cubicweb_rqlcontroller.rql_schema_holder import RqlIOSchemaHolder
 
-from cubicweb_rqlcontroller.predicates import match_all_http_headers
+from cubicweb_rqlcontroller.predicates import match_all_http_headers, match_basic_auth
 
 
 ARGRE = re.compile(r"__r(?P<ref>\d+)$")
@@ -227,6 +227,24 @@ class AnonMultipartRqlIOController(BaseRqlIOController):
     require_csrf = False
 
 
+class AuthenticatedMultipartRqlIOController(BaseRqlIOController):
+    """
+    RqlIOController with CSRF check deactivated for a user authenticated by
+    Authorization header, for multipart/form-data.
+
+    HTTP Basic Authentication is rejected, as it can be used in an HTML form.
+    """
+
+    __select__ = (
+        BaseRqlIOController.__select__
+        & match_all_http_headers("Authorization")
+        & ~match_basic_auth()
+        & match_request_content_type("multipart/form-data", mode="any")
+        & authenticated_user()
+    )
+    require_csrf = False
+
+
 class GetEntitiesRqlIOController(BaseRqlIOController):
     """GetEntitiesRqlIOController allow to get entities attributes
     from a RQL. Only attributes present in the RQL will be sent.
